import scrapy, re
from datetime import datetime, timedelta, tzinfo

## scrapy crawl noticias -t json --nolog -o noticias.json -a year=2017 -a month=3 -a day=22


TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class UTC(tzinfo):
    """clase para el 'time zone' (zona horaria)"""

    def utcoffset(self, dt):
        # zona horaria para sonora (tiempo del pacifico): utc-7
        return timedelta(hours=-7)

    def tzname(self, dt):
        # nombre de la zona horaria
        return 'UTC-7'


class NoticiasItem(scrapy.Item):
    title = scrapy.Field()
    text = scrapy.Field()
    date = scrapy.Field()
    location = scrapy.Field()
    author = scrapy.Field()
    topic = scrapy.Field()
    url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        tz = UTC()
        year = getattr(self, 'year', None)
        month = getattr(self, 'month', None)
        day = getattr(self, 'day', None)
        self.date = datetime(int(year),int(month),int(day),tzinfo=tz).isoformat('T')
        self.baseURL='http://diariodelyaqui.mx/'+year+'/'+month+'/'+day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        pagination = response.xpath('//ul[@class="page-numbers"]/li/a/@href').extract()

        if ( len(pagination) > 0 ):
            pagination = pagination[-2].strip('/')
            pages = int(pagination[pagination.rfind('/')+1:])

            for page in range(0,pages):
                if ( page == 0 ):
                    yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

                else:
                    yield scrapy.Request(url=self.baseURL+'/page/'+str(page+1), callback=self.parse_page)

        else:
            yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)


    def parse_page(self, response):
        for link in response.xpath('//h2[@class="entry-title"]/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''
        item['date'] = self.date
        item['title'] = response.xpath('//h1[@class="entry-title"]/text()').extract_first()
        item['topic'] = response.xpath('//ul[@class="post-categories"]/li/a/text()').extract_first()

        for paragraph in response.xpath('//div[@class="clearfix"]/p').extract():
            text += remove_tags(paragraph) + '\n'
        item['text'] = text

        item['url'] = response.url

        # print item['title']
        yield item

