import scrapy, re
from datetime import datetime, timedelta, tzinfo

'''
scrapy crawl noticias -t json --nolog -o noticias.json
'''

TAG_RE = re.compile(r'<[^>]+>')

def remove_tags(text):
    return TAG_RE.sub('', text)


class UTC(tzinfo):
	"""clase para el 'time zone' (zona horaria)"""

	def utcoffset(self, dt):
		# zona horaria para hidalgo (centro de mexico): utc-6
		return timedelta(hours=-6)

	def tzname(self, dt):
		# nombre de la zona horaria
		return 'UTC-6'


class NoticiasItem(scrapy.Item):
    title = scrapy.Field()
    text = scrapy.Field()
    date = scrapy.Field()
    location = scrapy.Field()
    author = scrapy.Field()
    topic = scrapy.Field()
    url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        self.tz = UTC()
        self.date_parser = {'enero': 1,      'febrero': 2,  'marzo': 3,      'abril': 4,
                            'mayo': 5,       'junio': 6,    'julio': 7,      'agosto': 8,
                            'septiembre': 9, 'octubre': 10, 'noviembre': 11, 'diciembre': 12}

        self.baseURL = 'http://www.elfinanciero.com.mx/rss'
        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        for link in response.xpath('//link/text()').extract()[1:]:
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        d = response.xpath('//*[@class="details-box"]/input[@id="publicado"]/@value').extract_first()
        d = d.replace('/',' ').replace(':',' ').split(' ')
        item['date'] = datetime(int(d[2]), self.date_parser[d[1].lower()], int(d[0]), int(d[3]), int(d[4]), tzinfo=self.tz).isoformat('T')
        item['topic'] = response.xpath('//*[@class="article-title"]/span/text()').extract_first()
        item['title'] = response.xpath('//*[@class="title"]/h1/text()').extract_first()
        for p in response.xpath('//*[@class="article-paragraphs"]/p').extract():
            text += remove_tags(p) + '\n'
        item['text'] = text
        item['author'] = response.xpath('//*[@class="details-box"]/input[@id="editor"]/@value').extract_first()
        item['url'] = response.url

        # print item['title']
        yield item

